(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     23139,        830]
NotebookOptionsPosition[     19351,        696]
NotebookOutlinePosition[     19840,        715]
CellTagsIndexPosition[     19797,        712]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Impedance Routing", "Title"],

Cell[CellGroupData[{

Cell["Board Parameters", "Section"],

Cell["All units in mils", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Boardthickness", "=", "93"}], ";", "  ", 
   RowBox[{"(*", " ", "mil", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Copper", "=", "1.0"}], ";"}], "                    ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"oz", "/", "sq"}], " ", "inch"}], ";", " ", 
    RowBox[{
     RowBox[{"1", "oz"}], " ", "=", " ", 
     RowBox[{"1.4", "mil"}]}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Corethickness", "=", "21"}], ";"}], "    ", 
  RowBox[{"(*", " ", "mil", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Prepregthickness", "=", "4.6"}], ";", "     ", 
  RowBox[{"(*", " ", "mil", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Er", "=", "4.2"}], ";", "                           ", 
  RowBox[{"(*", " ", 
   RowBox[{"dielectric", " ", "constant"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Layers", "=", "8"}], ";", "                     ", 
  RowBox[{"(*", "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"rule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"planethickness", "\[Rule]", "Prepregthickness"}], ",", 
     RowBox[{"planeplane", "\[Rule]", 
      RowBox[{
      "Corethickness", "+", "Prepregthickness", "+", "traceheight"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"corethickness", "\[Rule]", "Corethickness"}], ",", 
     RowBox[{"prepregthickness", "\[Rule]", "Prepregthickness"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"boardthickness", "\[Rule]", "Boardthickness"}], ",", 
     RowBox[{"er", "\[Rule]", "Er"}], ",", 
     RowBox[{"layers", "\[Rule]", "Layers"}], ",", 
     RowBox[{"copper", "\[Rule]", "Copper"}], ",", 
     RowBox[{"traceheight", "\[Rule]", 
      RowBox[{"copper", "*", "1.4"}]}]}], "}"}]}], ";", 
  "\[IndentingNewLine]"}]}], "Input",
 CellChangeTimes->{{3.429617748753625*^9, 3.429617801691125*^9}}],

Cell["\<\
Check board thickness from build-up\
\>", "Text",
 CellChangeTimes->{{3.429617765347375*^9, 3.429617769113*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"layers", "*", "traceheight"}], "+", 
   RowBox[{
    FractionBox["layers", "2"], "*", "prepregthickness"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox["layers", "2"], "-", "1"}], ")"}], "*", "corethickness"}]}],
   "//.", "rule"}]], "Input"],

Cell[BoxData["92.60000000000001`"], "Output",
 CellChangeTimes->{{3.429617770909875*^9, 3.4296178050505*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Microstrip", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Zm", "[", "w_", "]"}], ":=", 
  RowBox[{
   FractionBox["87", 
    SqrtBox[
     RowBox[{"er", "+", "1.41"}]]], 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"5.98", "planethickness"}], 
     RowBox[{
      RowBox[{"0.8", "w"}], "+", "traceheight"}]], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Speedm", ":=", 
  RowBox[{
   FractionBox["1", "12"], "1.017", 
   SqrtBox[
    RowBox[{
     RowBox[{"0.475", "er"}], "+", "0.67"}]], "     ", 
   RowBox[{"(*", " ", 
    RowBox[{"in", " ", 
     RowBox[{"ns", "/", "inch"}]}], " ", "*)"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Zm", "[", "9", "]"}], "//.", "rule"}]], "Input"],

Cell[BoxData["42.70817103813028`"], "Output",
 CellChangeTimes->{3.429617809534875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Zm", "[", "w", "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "50"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     RowBox[{"7.4750000000000005`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.011494252873563218`"}], " ", 
        SqrtBox[
         RowBox[{"1.41`", "\[InvisibleSpace]", "+", 
          RowBox[{"1.`", " ", "er"}]}]], " ", "Z0"}]], " ", 
      SuperscriptBox["planethickness", 
       "0.99999999999999999999999999991`15.906029430411715"]}], "-", 
     RowBox[{"1.25`", " ", "traceheight"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429617809816125*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "7.064413870514581`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429617809816125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Speedm", "//.", "rule"}]], "Input"],

Cell[BoxData["0.13835291490424043`"], "Output",
 CellChangeTimes->{3.429617809847375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential Microstrip", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZmDiff", "[", 
   RowBox[{"w_", ",", "s_"}], "]"}], ":=", 
  RowBox[{"2", 
   RowBox[{"Zm", "[", "w", "]"}], 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"0.48", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "0.96"}], " ", 
        FractionBox["s", "planethickness"]}], "]"}]}]}], ")"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ZmDiff", "[", 
   RowBox[{"6", ",", "6"}], "]"}], "//.", "rule"}]], "Input"],

Cell[BoxData["94.43461214379565`"], "Output",
 CellChangeTimes->{3.429617927597375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ZmDiff", "[", 
      RowBox[{"w", ",", "6"}], "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "100"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     RowBox[{"7.4750000000000005`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"25.`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"5.76`", "/", "planethickness"}]], " ", 
         SqrtBox[
          RowBox[{"1.41`", "\[InvisibleSpace]", "+", 
           RowBox[{"1.`", " ", "er"}]}]], " ", "Z0"}], 
        RowBox[{"2088.`", "\[InvisibleSpace]", "-", 
         RowBox[{"4350.`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"5.76`", "/", "planethickness"}]]}]}]]], " ", 
      "planethickness"}], "-", 
     RowBox[{"1.25`", " ", "traceheight"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429617927784875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "5.348516310164952`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429617927784875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stripline", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Z", "[", "w_", "]"}], ":=", 
  RowBox[{
   FractionBox["60", 
    SqrtBox["er"]], 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"4", " ", "planeplane"}], 
     RowBox[{"0.67", "\[Pi]", " ", "w", 
      RowBox[{"(", 
       RowBox[{"0.8", "+", 
        RowBox[{"traceheight", "/", "w"}]}], ")"}]}]], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Speed", ":=", 
  RowBox[{
   RowBox[{"1", "/", "12"}], " ", "1.017", 
   SqrtBox["Er"], "      ", 
   RowBox[{"(*", " ", 
    RowBox[{"in", " ", 
     RowBox[{"ns", "/", "inch"}]}], " ", "*)"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Z", "[", "5", "]"}], "//.", "rule"}], "//", "N"}]], "Input"],

Cell[BoxData["65.91658354935613`"], "Output",
 CellChangeTimes->{{3.42961798026925*^9, 3.42961798908175*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Z", "[", "w", "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "50"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "::", "\<\"ifun\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Inverse functions are being used by \\!\\(Solve\\), so \
some solutions may not be found; use Reduce for complete solution \
information. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/Solve/ifun\\\", ButtonNote -> \
\\\"Solve::ifun\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.42961798064425*^9, 3.42961798914425*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{"1.25`", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1.9003575294554667`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "0.016666666666666666`"}], " ", 
           SqrtBox["er"], " ", "Z0"}]], " ", 
         SuperscriptBox["planeplane", "1.`"]}], "-", 
        RowBox[{"1.`", " ", "traceheight"}]}], ")"}], 
      "1.`15.954589770191005"]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.4296179806755*^9, 3.42961798914425*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "9.875457802127892`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.4296179806755*^9, 3.429617989159875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Speed", "//.", "rule", "                       ", 
  RowBox[{"(*", " ", 
   RowBox[{"ns", "/", "inch"}], " ", "*)"}]}]], "Input"],

Cell[BoxData["0.1736858154830152`"], "Output",
 CellChangeTimes->{{3.429617980722375*^9, 3.429617989191125*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential Stripline", "Section"],

Cell["\<\
w: width, s: separation (mil)
result in Ohms\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZDiff", "[", 
   RowBox[{"w_", ",", "s_"}], "]"}], ":=", 
  RowBox[{"2", 
   RowBox[{"Z", "[", "w", "]"}], 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"0.347", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "2.9"}], " ", 
        FractionBox["s", "planeplane"]}], "]"}]}]}], ")"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ZDiff", "[", 
   RowBox[{"5", ",", "8"}], "]"}], "//.", "rule"}]], "Input"],

Cell[BoxData["112.46080377813348`"], "Output",
 CellChangeTimes->{3.429617995128625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ZDiff", "[", 
      RowBox[{"w", ",", "8"}], "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "100"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     RowBox[{"2.375446911819333`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"25.`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"23.2`", "/", "planeplane"}]], " ", 
         SqrtBox["er"], " ", "Z0"}], 
        RowBox[{"1041.`", "\[InvisibleSpace]", "-", 
         RowBox[{"3000.`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"23.2`", "/", "planeplane"}]]}]}]]], " ", "planeplane"}], 
     "-", 
     RowBox[{"1.25`", " ", "traceheight"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429617995284875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "6.912552465879912`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4296179953005*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dual Stripline", "Section"],

Cell[TextData[{
 "stacked on top between to planes\nlayer model: prepreg + core + prepreg\n\
conditions: 0.1 < ",
 Cell[BoxData[
  FormBox[
   FractionBox["w", "prepregthickness"], TraditionalForm]]],
 " < 2.0 and ",
 Cell[BoxData[
  FormBox[
   FractionBox["traceheight", "prepregthickness"], TraditionalForm]]],
 "< 0.25\nw: width"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZDual", "[", "w_", "]"}], ":=", 
  RowBox[{
   FractionBox["80", 
    SqrtBox["er"]], 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"1.9", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", "prepregthickness"}], "+", "traceheight"}], ")"}]}],
      
     RowBox[{
      RowBox[{"0.8", " ", "w"}], "+", "traceheight"}]], "]"}], 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox["prepregthickness", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
        "prepregthickness", "+", "corethickness", "+", "traceheight"}], 
        ")"}]}]]}], ")"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpeedDual", "=", 
  RowBox[{
   FractionBox["1", "12"], "1.017", 
   SqrtBox["er"], "     ", 
   RowBox[{"(*", " ", 
    RowBox[{"in", " ", 
     RowBox[{"ns", "/", "inch"}]}], " ", "*)"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"0.08474999999999999`", " ", 
  SqrtBox["er"]}]], "Output",
 CellChangeTimes->{3.429618155909875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ZDual", "[", "6", "]"}], "//.", "rule"}]], "Input"],

Cell[BoxData["44.031743372087774`"], "Output",
 CellChangeTimes->{3.429618155941125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ZDual", "[", "w", "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], 
  "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "50"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"1.`", " ", 
         SqrtBox["er"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1.`", " ", "corethickness"}], "+", 
           RowBox[{"1.`", " ", "prepregthickness"}], "+", 
           RowBox[{"1.`", " ", "traceheight"}]}], ")"}], " ", "Z0"}], 
        RowBox[{
         RowBox[{"80.`", " ", "corethickness"}], "+", 
         RowBox[{"60.`", " ", "prepregthickness"}], "+", 
         RowBox[{"80.`", " ", "traceheight"}]}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4.75`", " ", "prepregthickness"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2.375`", "\[InvisibleSpace]", "-", 
          RowBox[{"1.25`", " ", 
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{
              SqrtBox["er"], " ", 
              RowBox[{"(", 
               RowBox[{
               "corethickness", "+", "prepregthickness", "+", "traceheight"}],
                ")"}], " ", "Z0"}], 
             RowBox[{
              RowBox[{"80.`", " ", "corethickness"}], "+", 
              RowBox[{"60.`", " ", "prepregthickness"}], "+", 
              RowBox[{"80.`", " ", "traceheight"}]}]]]}]}], ")"}], " ", 
        "traceheight"}]}], ")"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429618156128625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "4.856143391539851`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429618156128625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpeedDual", "//.", "rule", "                       ", 
  RowBox[{"(*", " ", 
   RowBox[{"ns", "/", "inch"}], " ", "*)"}]}]], "Input"],

Cell[BoxData["0.1736858154830152`"], "Output",
 CellChangeTimes->{3.429618156159875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Asymmetric Stripline", "Section"],

Cell[TextData[{
 "hhh: smaller layer thickness\nhhh1: greater layer thickness\n",
 "conditions: 0.1 < ",
 Cell[BoxData[
  FormBox[
   FractionBox["w", 
    RowBox[{"smaller", " ", "layer", " ", "thickness"}]], TraditionalForm]]],
 " < 2.0 and ",
 Cell[BoxData[
  FormBox[
   FractionBox["traceheight", 
    RowBox[{"smaller", " ", "layer", " ", "thickness"}]], TraditionalForm]]],
 "< 0.25"
}], "Text"],

Cell[BoxData[{
 RowBox[{"Off", "[", 
  RowBox[{"ReplaceAll", "::", "reps"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Za", "[", "w_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    FractionBox["80", 
     SqrtBox["er"]], 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"1.9", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", "hhh"}], "+", "traceheight"}], ")"}]}], 
      RowBox[{
       RowBox[{"0.8", " ", "w"}], "+", "traceheight"}]], "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["hhh", 
       RowBox[{"4", " ", "hhh1"}]]}], ")"}]}], "/.", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"prepregthickness", ">", "corethickness"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hhh", "\[Rule]", "corethickness"}], ",", 
       RowBox[{"hhh1", "\[Rule]", "prepregthickness"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hhh1", "\[Rule]", "corethickness"}], ",", 
       RowBox[{"hhh", "\[Rule]", "prepregthickness"}]}], "}"}]}], 
    "]"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Speeda", ":=", 
  RowBox[{
   FractionBox["1", "12"], " ", "1.017", 
   SqrtBox["Er"], "      ", 
   RowBox[{"(*", " ", 
    RowBox[{"in", " ", 
     RowBox[{"ns", "/", "inch"}]}], " ", "*)"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Za", "[", "5", "]"}], "//.", "rule"}], "//", "N"}]], "Input"],

Cell[BoxData["48.56958436407749`"], "Output",
 CellChangeTimes->{3.42961814808175*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Za", "[", "w", "]"}], "//.", "rule"}], ")"}], "\[Equal]", 
     "Z0"}], ",", "w"}], "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "50"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "1.75`"}], "+", 
     RowBox[{"25.174999999999986`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.027101507063621105`"}], " ", "Z0"}]]}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.429618148128625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "4.743333826029893`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429618148128625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Speeda", "//.", "rule", "                       ", 
  RowBox[{"(*", " ", 
   RowBox[{"ns", "/", "inch"}], " ", "*)"}]}]], "Input"],

Cell[BoxData["0.1736858154830152`"], "Output",
 CellChangeTimes->{3.429618148159875*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{925, 1028},
WindowMargins->{{385, Automatic}, {Automatic, -4}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 34, 0, 83, "Title"],
Cell[CellGroupData[{
Cell[649, 27, 35, 0, 71, "Section"],
Cell[687, 29, 33, 0, 29, "Text"],
Cell[723, 31, 1884, 43, 212, "Input"],
Cell[2610, 76, 122, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[2757, 83, 313, 10, 45, "Input"],
Cell[3073, 95, 109, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3231, 102, 29, 0, 71, "Section"],
Cell[3263, 104, 316, 11, 51, "Input"],
Cell[3582, 117, 278, 9, 45, "Input"],
Cell[CellGroupData[{
Cell[3885, 130, 83, 2, 31, "Input"],
Cell[3971, 134, 87, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4095, 140, 294, 9, 52, "Input"],
Cell[4392, 151, 594, 15, 42, "Output"],
Cell[4989, 168, 162, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5188, 177, 59, 1, 31, "Input"],
Cell[5250, 180, 89, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5388, 187, 42, 0, 71, "Section"],
Cell[5433, 189, 369, 12, 47, "Input"],
Cell[CellGroupData[{
Cell[5827, 205, 111, 3, 31, "Input"],
Cell[5941, 210, 87, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6065, 216, 326, 10, 52, "Input"],
Cell[6394, 228, 793, 20, 55, "Output"],
Cell[7190, 250, 162, 4, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7401, 260, 28, 0, 71, "Section"],
Cell[7432, 262, 363, 12, 51, "Input"],
Cell[7798, 276, 232, 7, 34, "Input"],
Cell[CellGroupData[{
Cell[8055, 287, 107, 3, 31, "Input"],
Cell[8165, 292, 109, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8311, 298, 293, 9, 52, "Input"],
Cell[8607, 309, 512, 10, 21, "Message"],
Cell[9122, 321, 600, 16, 47, "Output"],
Cell[9725, 339, 184, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9946, 348, 153, 3, 31, "Input"],
Cell[10102, 353, 112, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10263, 360, 41, 0, 71, "Section"],
Cell[10307, 362, 68, 3, 47, "Text"],
Cell[10378, 367, 363, 12, 47, "Input"],
Cell[CellGroupData[{
Cell[10766, 383, 110, 3, 31, "Input"],
Cell[10879, 388, 88, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11004, 394, 325, 10, 52, "Input"],
Cell[11332, 406, 689, 18, 55, "Output"],
Cell[12024, 426, 160, 4, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12233, 436, 33, 0, 71, "Section"],
Cell[12269, 438, 345, 11, 94, "Text"],
Cell[12617, 451, 638, 22, 51, "Input"],
Cell[CellGroupData[{
Cell[13280, 477, 227, 7, 45, "Input"],
Cell[13510, 486, 124, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13671, 494, 86, 2, 31, "Input"],
Cell[13760, 498, 88, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13885, 504, 297, 9, 52, "Input"],
Cell[14185, 515, 1476, 39, 115, "Output"],
Cell[15664, 556, 162, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15863, 565, 157, 3, 31, "Input"],
Cell[16023, 570, 88, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16160, 577, 39, 0, 71, "Section"],
Cell[16202, 579, 402, 13, 76, "Text"],
Cell[16607, 594, 1047, 32, 115, "Input"],
Cell[17657, 628, 231, 7, 45, "Input"],
Cell[CellGroupData[{
Cell[17913, 639, 108, 3, 31, "Input"],
Cell[18024, 644, 86, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18147, 650, 357, 11, 52, "Input"],
Cell[18507, 663, 357, 11, 33, "Output"],
Cell[18867, 676, 162, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19066, 685, 154, 3, 31, "Input"],
Cell[19223, 690, 88, 1, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

